@@ -35,21 +35,21 @@ def main():
     files = [file for file in files if file in FILES_TO_COPY]
     files = [file for file in files if os.path.isfile(os.path.join(package_path, file))]
 
-    print(Style.BRIGHT + Fore.GREEN + f"Package Path: {package_path}")
-    print(Style.BRIGHT + Fore.GREEN + f"Project Path: {project_path}")
+    print(Style.BRIGHT + Fore.GREEN + "Package Path: " + package_path)
+    print(Style.BRIGHT + Fore.GREEN + "Project Path: " + project_path)
 
     for file in files:
         file_name_path = os.path.join(package_path, file)
         file_name_project_path = os.path.join(project_path, file)
         shutil.copy(file_name_path, file_name_project_path)
-        print(Fore.GREEN + f"Added file: {file}")
+        print(Fore.GREEN + f"Added file: " + file)
 
-    execute_command("pip install pre-commit==2.9.2")
+    execute_command("python2 -m pip install pre-commit==2.9.2")
     print('find "'+project_path+'" -type f -name ".pre-commit-config.yaml" -exec git add {} \;')
     execute_command('find "'+project_path+'" -type f -name ".pre-commit-config.yaml" -exec git add {} \;')
     execute_command("pre-commit autoupdate --bleeding-edge")
     execute_command("pre-commit install")
-    execute_command("pip install pylint==1.9.5")
+    execute_command("python2 -m pip install pylint==1.9.5")
 
     print(Style.BRIGHT + Fore.GREEN + "Paraty Pre-Commit Installed!!")
 
